============
Installation
============

At the command line::

    $ easy_install gunicorn_cache

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv gunicorn_cache
    $ pip install gunicorn_cache
